FabIO Viewer
============

fabio_viewer is a simple diffraction image viewer based on matplotlib and PyQt4.

.. image:: ../img/viewer.png

.. command-output:: fabio_viewer --help
    :nostderr:

This tool is deprecated and one should prefer `silx view` as generic image viewer.
